
/*
 *  CPlan solves planning problems formulated as constraint satisfaction
 *  problems.
 *
 *  Copyright (C) 1999  Peter van Beek and Xinguang Chen
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.  See the GNU General Public License
 *  for more details (see the file called Copying or contact the Free
 *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA).
 */

/*
 *  Variable types for blocks world planning problems.
 */
#define  ABOVE	   0
#define  BELOW	   1
#define  ARM	   2

/*
 *  Value types for blocks world planning problems.
 */
#define  BLOCK	   0
#define  CLEAR	   1
#define  TABLE     2
#define  EMPTY     3
#define  HELD      4

/*
 *  Types of constraints for state-based approach.
 */
#define  DISTANCE_ABOVE_CONSTRAINT	    0
#define  DISTANCE_BELOW_CONSTRAINT	    1
#define  DISTANCE2_ABOVE_CONSTRAINT	    2
#define  DISTANCE2_BELOW_CONSTRAINT	    3
#define  SAME_BLOCK_CONSTRAINT		    4
#define  DIFF_BLOCK_CONSTRAINT		    5
#define  ACTION_ABOVE_CONSTRAINT	    6
#define  ACTION_BELOW_CONSTRAINT	    7
#define  USELESS2_ACTIONS_CONSTRAINT	    8
#define  USELESS3_ACTIONS_CONSTRAINT	    9
#define  USELESS4_ACTIONS_CONSTRAINT	   10
#define  SYMMETRY_CONSTRAINT		   11
#define  USEFUL_ACTION_CONSTRAINT	   12
#define  LAST				   13	/* marks end */

/*
 *  Struct for an instance of the blocks problems.
 */
typedef struct {
    int  problem;
    int	 blocks;
    int  arms;
    int  *init_above;
    int  *init_below;
    int  *goal_above;
    int  *goal_below;
    int  *init_depth;
    int  *goal_depth;
} I_type;

/*
 *  Routines available for an instance of the blocks world problems.
 */
void    get_instance();
void    print_instance();
void    dump_instance();

int     get_num_blocks();
int     get_upper_bound();
int     get_lower_bound();

int	get_init_above();
int	get_init_below();
int	get_goal_above();
int	get_goal_below();

int	clear_in_init();
int	clear_in_goal();
int	on_table_in_init();
int	on_table_in_goal();

int	get_init_depth();
int	get_goal_depth();

