
/*
 *  CPlan solves planning problems formulated as constraint satisfaction
 *  problems.
 *
 *  Copyright (C) 1999  Peter van Beek and Xinguang Chen
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation.  See the GNU General Public License
 *  for more details (see the file called Copying or contact the Free
 *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA).
 */

#include "blocks.h"
#include "../Share/global.h"
#include "../Share/csp.h"

void
process_solution( C, solution )
    CSP_type    *C;
    int		*solution;
{
    int		t, i;
    int		v1, v2, x1, x2;
    VALA	a1, a2, b1, b2;

    verify_solution( C, solution );

    for( t = 0; t <= C->time-1; t++ ) {
	printf( "Action at time %2d: ", t+1 );
	/*
	 * Block variables
	 */
        for( i = 1; i <= get_num_blocks(); i++ ) {
	    v1 = get_var( C, t,   ABOVE, i );
	    v2 = get_var( C, t+1, ABOVE, i );
	    a1 = C->value_attribute[v1][solution[v1]];
	    a2 = C->value_attribute[v2][solution[v2]];

	    if( a1.type == CLEAR &&
	        a2.type == HELD ) {

		x1 = get_var( C, t,   BELOW, i );
		x2 = get_var( C, t+1, BELOW, i );
		b1 = C->value_attribute[x1][solution[x1]];
		b2 = C->value_attribute[x2][solution[x2]];

		if( b1.type == TABLE &&
		    b2.type == HELD ) {
		    printf( "\tpickup block %d from table\n", i );
		}
		else
		if( b1.type == BLOCK &&
		    b2.type == HELD ) {
		    printf( "\tunstack block %d from block %d\n",
			i, b1.number );
		}
	    }
	    else
	    if( a1.type == HELD &&
	        a2.type == CLEAR ) {

		x1 = get_var( C, t,   BELOW, i );
		x2 = get_var( C, t+1, BELOW, i );
		b1 = C->value_attribute[x1][solution[x1]];
		b2 = C->value_attribute[x2][solution[x2]];

		if( b1.type == HELD &&
		    b2.type == TABLE ) {
		    printf( "\tputdown block %d onto table\n", i );
		}
		else
		if( b1.type == HELD &&
		    b2.type == BLOCK ) {
		    printf( "\tstack block %d onto block %d\n",
			i, b2.number );
		}
	    }
        }
    }
}

